import { ThunkAction } from 'redux-thunk';
import { Repository } from './interfaces';
import { Action } from './types';
export interface CreateFetchResourceOptions {
    silentAlready?: boolean;
    ttl?: number;
}
/**
 * Create action creator function to fetch resource.
 *
 * @param {string} resourceName Resource name, used to distinguish different resources.
 * @param {string} id Resource ID.
 * @param {Function} repositoryExtractor Callback consuming state as a parameter and returning the repository object.
 * @param {Function} fetchFunction Callback implementing fetch algorithm and calling the first parameter passed with the
 *                                 result or the second with an error.
 * @param {object} [options={}] Options.
 * @returns {Function} Function to be used as an action creator.
 */
export declare const createFetchResource: <TState, TData, TError>(resourceName: string, id: string, repositoryExtractor: (state: TState) => Repository<TData, TError>, fetchFunction: (dispatchReceived: (data: TData) => void, dispatchFailed: (error: TError) => void) => void, options?: CreateFetchResourceOptions) => ThunkAction<void, TState, null, Action<TData, TError>>;
/**
 * Create action creator function to reset resources.
 *
 * @param {string} resourceName Resource name, used to distinguish different resources.
 * @returns {Function} Function to be used as an action creator.
 */
export declare const createResetResources: <TState, TData, TError>(resourceName: string) => ThunkAction<void, TState, null, Action<TData, TError>>;
