"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.repositoryReducer = exports.isResourceAction = void 0;

var _repository = require("./repository");

var _resource = require("./resource");

var T = _interopRequireWildcard(require("./types"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Check if the action type relates to the named resource and should be handled by the reducer of
 * this package.
 *
 * @param {string} resourceName
 * @param {object} action
 * @returns {boolean}
 */
var isResourceAction = function isResourceAction(resourceName, action) {
  return Boolean(action.payload && action.payload.resourceName && action.payload.resourceName === resourceName && T.ALL_TYPES.indexOf(action.type) >= 0);
};
/**
 * Function consuming repository and action objects and returning updated repository object. If the
 * action passes `isResourceAction()` test, your own reducer should delegate the action handling to
 * this function.
 *
 * @param {object} repository
 * @param {object} action
 * @returns {object} Updated repository.
 */


exports.isResourceAction = isResourceAction;

var repositoryReducer = function repositoryReducer(repository, action) {
  switch (action.type) {
    case T.FETCH_RESOURCE_FAILED:
      return (0, _repository.pushResource)(repository, (0, _resource.createFailed)(action.payload.id, action.payload.error));

    case T.FETCH_RESOURCE_RECEIVED:
      return (0, _repository.pushResource)(repository, (0, _resource.createReceived)(action.payload.id, action.payload.data));

    case T.FETCH_RESOURCE_REQUESTED:
      return (0, _repository.pushResource)(repository, (0, _resource.createRequested)(action.payload.id));

    case T.RESOURCES_RESET:
      return (0, _repository.createInitialState)();

    default:
      return repository;
  }
};

exports.repositoryReducer = repositoryReducer;