import { Repository, Resource } from './interfaces';
/**
 * Create initial repository state.
 *
 * @returns {{
 *   allIds: Array<string>,
 *   byId: object
 * }}
 */
export declare const createInitialState: <TData, TError>() => Repository<TData, TError>;
/**
 * Get resource from the repository by ID.
 *
 * @param {object} repository
 * @param {string} id
 * @returns {object|null} Resource object.
 */
export declare const getResourceById: <TData, TError>(repository: Repository<TData, TError>, id: string) => Resource<TData, TError> | null;
/**
 * Get array of resources from the repository by array of IDs.
 *
 * @param {object} repository
 * @param {Array<string>} ids
 * @returns {Array<object>} Resources array.
 */
export declare const getResourcesArrayByIds: <TData, TError>(repository: Repository<TData, TError>, ids: string[]) => Resource<TData, TError>[];
/**
 * Push resource to the repository.
 *
 * @param {object} repository
 * @param {object} resource
 * @returns {object} Updated repository.
 */
export declare const pushResource: <TData, TError>(repository: Repository<TData, TError>, resource: Resource<TData, TError>) => Repository<TData, TError>;
/**
 * Push array of resources to the repository.
 *
 * @param {object} repository
 * @param {Array<object>} resources
 * @returns {object} Updated repository.
 */
export declare const pushResourcesArray: <TData, TError>(repository: Repository<TData, TError>, resources: Resource<TData, TError>[]) => Repository<TData, TError>;
/**
 * Merge resources from the first repository with received resources from the second one.
 *
 * @param {object} first
 * @param {object} second
 * @returns {object} Result repository.
 */
export declare const mergeRepositories: <TData, TError>(first: Repository<TData, TError>, second: Repository<TData, TError>) => Repository<TData, TError>;
