"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mergeRepositories = exports.pushResourcesArray = exports.pushResource = exports.getResourcesArrayByIds = exports.getResourceById = exports.createInitialState = void 0;

var S = _interopRequireWildcard(require("./statuses"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Merge resources IDs.
 *
 * @param {Array<string>} ids
 * @returns {Array<string>}
 * @private
 */
var mergeResourcesIds = function mergeResourcesIds() {
  var _ref;

  return Array.from(new Set((_ref = []).concat.apply(_ref, arguments)));
};
/**
 * Create initial repository state.
 *
 * @returns {{
 *   allIds: Array<string>,
 *   byId: object
 * }}
 */


var createInitialState = function createInitialState() {
  return {
    allIds: [],
    byId: {}
  };
};
/**
 * Get resource from the repository by ID.
 *
 * @param {object} repository
 * @param {string} id
 * @returns {object|null} Resource object.
 */


exports.createInitialState = createInitialState;

var getResourceById = function getResourceById(repository, id) {
  return repository.byId[id] || null;
};
/**
 * Get array of resources from the repository by array of IDs.
 *
 * @param {object} repository
 * @param {Array<string>} ids
 * @returns {Array<object>} Resources array.
 */


exports.getResourceById = getResourceById;

var getResourcesArrayByIds = function getResourcesArrayByIds(repository, ids) {
  return ids.map(function (id) {
    return getResourceById(repository, id);
  }).filter(function (resource) {
    return !!resource;
  });
};
/**
 * Push resource to the repository.
 *
 * @param {object} repository
 * @param {object} resource
 * @returns {object} Updated repository.
 */


exports.getResourcesArrayByIds = getResourcesArrayByIds;

var pushResource = function pushResource(repository, resource) {
  return {
    allIds: mergeResourcesIds(repository.allIds, [resource.id]),
    byId: _objectSpread(_objectSpread({}, repository.byId), {}, _defineProperty({}, resource.id, resource))
  };
};
/**
 * Push array of resources to the repository.
 *
 * @param {object} repository
 * @param {Array<object>} resources
 * @returns {object} Updated repository.
 */


exports.pushResource = pushResource;

var pushResourcesArray = function pushResourcesArray(repository, resources) {
  var byId = {};
  var resourcesIds = resources.map(function (resource) {
    var id = resource.id;
    byId[id] = resource;
    return id;
  });
  return {
    allIds: mergeResourcesIds(repository.allIds, resourcesIds),
    byId: _objectSpread(_objectSpread({}, repository.byId), byId)
  };
};
/**
 * Merge resources from the first repository with received resources from the second one.
 *
 * @param {object} first
 * @param {object} second
 * @returns {object} Result repository.
 */


exports.pushResourcesArray = pushResourcesArray;

var mergeRepositories = function mergeRepositories(first, second) {
  var byId = _objectSpread({}, first.byId);

  var newIds = [];
  second.allIds.forEach(function (id) {
    if (second.byId[id].status === S.RECEIVED && !first.byId[id]) {
      newIds.push(id);
      byId[id] = second.byId[id];
    }
  });
  return {
    allIds: mergeResourcesIds(first.allIds, newIds),
    byId: byId
  };
};

exports.mergeRepositories = mergeRepositories;