import { FailedResource, ReceivedResource, RequestedResource, Resource } from './interfaces';
/**
 * Create an object representing failed resource.
 *
 * @param {string} id
 * @param {*} error
 * @returns {{error: *, id: string, status: string, timestamp: number}}
 */
export declare const createFailed: <TError>(id: string, error: TError) => FailedResource<TError>;
/**
 * Create an object representing received resource.
 *
 * @param {string} id
 * @param {*} data
 * @returns {{data: *, id: string, status: string, timestamp: number}}
 */
export declare const createReceived: <TData>(id: string, data: TData) => ReceivedResource<TData>;
/**
 * Create an object representing requested resource.
 *
 * @param {string} id
 * @returns {{id: string, status: string}}
 */
export declare const createRequested: (id: string) => RequestedResource;
/**
 * Extract data from the object representing resource.
 *
 * @param {object|null} resource
 * @returns {*}
 */
export declare const extractData: <TData, TError>(resource: Resource<TData, TError> | null) => TData | null;
/**
 * Extract error from the object representing resource.
 *
 * @param {object|null} resource
 * @returns {*}
 */
export declare const extractError: <TData, TError>(resource: Resource<TData, TError> | null) => TError | null;
/**
 * Check if resource is expired.
 *
 * @param {object|null} resource
 * @param {number} ttl
 * @returns {boolean}
 */
export declare const isExpired: <TData, TError>(resource: Resource<TData, TError> | null, ttl: number) => boolean;
/**
 * Check if resource is failed.
 *
 * @param {object|null} resource
 * @returns {boolean}
 */
export declare const isFailed: <TData, TError>(resource: Resource<TData, TError> | null) => boolean;
/**
 * Check if resource is received.
 *
 * @param {object|null} resource
 * @returns {boolean}
 */
export declare const isReceived: <TData, TError>(resource: Resource<TData, TError> | null) => boolean;
/**
 * Check if resource is requested.
 *
 * @param {object|null} resource
 * @returns {boolean}
 */
export declare const isRequested: <TData, TError>(resource: Resource<TData, TError> | null) => boolean;
