"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isRequested = exports.isReceived = exports.isFailed = exports.isExpired = exports.extractError = exports.extractData = exports.createRequested = exports.createReceived = exports.createFailed = void 0;

var S = _interopRequireWildcard(require("./statuses"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Create an object representing failed resource.
 *
 * @param {string} id
 * @param {*} error
 * @returns {{error: *, id: string, status: string, timestamp: number}}
 */
var createFailed = function createFailed(id, error) {
  return {
    error: error,
    id: id,
    status: S.FAILED,
    timestamp: Date.now()
  };
};
/**
 * Create an object representing received resource.
 *
 * @param {string} id
 * @param {*} data
 * @returns {{data: *, id: string, status: string, timestamp: number}}
 */


exports.createFailed = createFailed;

var createReceived = function createReceived(id, data) {
  return {
    data: data,
    id: id,
    status: S.RECEIVED,
    timestamp: Date.now()
  };
};
/**
 * Create an object representing requested resource.
 *
 * @param {string} id
 * @returns {{id: string, status: string}}
 */


exports.createReceived = createReceived;

var createRequested = function createRequested(id) {
  return {
    id: id,
    status: S.REQUESTED
  };
};
/**
 * Extract data from the object representing resource.
 *
 * @param {object|null} resource
 * @returns {*}
 */


exports.createRequested = createRequested;

var extractData = function extractData(resource) {
  return resource && resource.data ? resource.data : null;
};
/**
 * Extract error from the object representing resource.
 *
 * @param {object|null} resource
 * @returns {*}
 */


exports.extractData = extractData;

var extractError = function extractError(resource) {
  return resource && resource.error ? resource.error : null;
};
/**
 * Check if resource is expired.
 *
 * @param {object|null} resource
 * @param {number} ttl
 * @returns {boolean}
 */


exports.extractError = extractError;

var isExpired = function isExpired(resource, ttl) {
  return Boolean(resource && resource.timestamp && Date.now() > resource.timestamp + ttl);
};
/**
 * Check if resource is failed.
 *
 * @param {object|null} resource
 * @returns {boolean}
 */


exports.isExpired = isExpired;

var isFailed = function isFailed(resource) {
  return Boolean(resource && resource.status === S.FAILED);
};
/**
 * Check if resource is received.
 *
 * @param {object|null} resource
 * @returns {boolean}
 */


exports.isFailed = isFailed;

var isReceived = function isReceived(resource) {
  return Boolean(resource && resource.status === S.RECEIVED);
};
/**
 * Check if resource is requested.
 *
 * @param {object|null} resource
 * @returns {boolean}
 */


exports.isReceived = isReceived;

var isRequested = function isRequested(resource) {
  return Boolean(resource && resource.status === S.REQUESTED);
};

exports.isRequested = isRequested;